@@ -5,11 +5,6 @@ test_that ('trim_osm_data', {
                q0 <- opq (bbox = c(1, 1, 5, 5))
                x0 <- osmdata_sf (q0, "../osm-multi.osm")
                bb <- cbind (c (2, 3), c (2, 3))
-               if (!any (grepl ("package:sf", search ())))
-                   expect_message (x1 <- trim_osmdata (x0, bb_poly = bb),
-                       "It is generally necessary to pre-load the sf package")
-               else
-                   expect_silent (x1 <- trim_osmdata (x0, bb_poly = bb))
                require (sf)
                expect_silent (x1 <- trim_osmdata (x0, bb_poly = bb))
                expect_equal (nrow (x1$osm_points), 0)
